==> kdelibs-3.0.1.tar.bz2: kdelibs-3.0.1/khtml/misc/helper.h <==
/*
 * This file is part of the CSS implementation for KDE.
 *
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: helper.h,v 1.10 2002/02/10 13:32:45 knoll Exp $
 */
#ifndef html_helper_h
#define html_helper_h

#include <qcolor.h>
class QPainter;
#include <qfontmetrics.h>
#include <qfont.h>

namespace khtml
{
    void setNamedColor(QColor &color, const QString &name);

    extern QPainter *printpainter;
    void setPrintPainter( QPainter *printer );

    //enumerator for findSelectionNode
    enum FindSelectionResult { SelectionPointBefore,
			       SelectionPointAfter,
			       SelectionPointInside,
			       // the next two are only used inside one line in RenderText
			       // to get BiDi contexts right.
			       SelectionPointBeforeInLine,
			       SelectionPointAfterInLine };
};

#endif

==> kdelibs-3.1.tar.bz2: kdelibs-3.1/khtml/misc/helper.h <==
/*
 * This file is part of the CSS implementation for KDE.
 *
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: helper.h,v 1.13 2002/10/27 17:13:23 mueller Exp $
 */
#ifndef html_helper_h
#define html_helper_h

#include <qcolor.h>
class QPainter;
#include <qfontmetrics.h>
#include <qfont.h>

namespace khtml
{
    const QRgb transparentColor = 0x00000000;
    const QRgb invalidColor     = 0x00000001;
    const QRgb invertedColor    = 0x00000002;
    const QRgb defaultTextColor = 0x00000003;

    QRgb parseColor(QString name, bool strictParsing);

    extern QPainter *printpainter;
    void setPrintPainter( QPainter *printer );

    //enumerator for findSelectionNode
    enum FindSelectionResult { SelectionPointBefore,
			       SelectionPointAfter,
			       SelectionPointInside,
			       // the next two are only used inside one line in RenderText
			       // to get BiDi contexts right.
			       SelectionPointBeforeInLine,
			       SelectionPointAfterInLine };
};

#endif
